/*
 * This file is auto-generated, do not modify!
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#pragma once
#include <libfwupd/fwupd-build.h>
/**
 * FwupdBiosSettingKind:
 *
 * The type of BIOS setting.
 */
typedef enum {
    /**
     * FWUPD_BIOS_SETTING_KIND_UNKNOWN:
     *
     * BIOS setting type is unknown.
     */
    FWUPD_BIOS_SETTING_KIND_UNKNOWN,
    /**
     * FWUPD_BIOS_SETTING_KIND_ENUMERATION:
     *
     * BIOS setting that has enumerated possible values.
     */
    FWUPD_BIOS_SETTING_KIND_ENUMERATION,
    /**
     * FWUPD_BIOS_SETTING_KIND_INTEGER:
     *
     * BIOS setting that is an integer.
     */
    FWUPD_BIOS_SETTING_KIND_INTEGER,
    /**
     * FWUPD_BIOS_SETTING_KIND_STRING:
     *
     * BIOS setting that accepts a string.
     */
    FWUPD_BIOS_SETTING_KIND_STRING,
}  FwupdBiosSettingKind;
#define FWUPD_BIOS_SETTING_KIND_LAST 4
