/*
 * This file is auto-generated, do not modify!
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#pragma once
#include <libfwupd/fwupd-build.h>
/**
 * FwupdCodecFlags:
 *
 * The flags to use when converting data from one form to another.
 */
typedef enum {
    /**
     * FWUPD_CODEC_FLAG_NONE:
     *
     * No flags set.
     */
    FWUPD_CODEC_FLAG_NONE = 0,
    /**
     * FWUPD_CODEC_FLAG_TRUSTED:
     *
     * Include values that may be regarded as trusted or sensitive.
     */
    FWUPD_CODEC_FLAG_TRUSTED = 1 << 0,
    /**
     * FWUPD_CODEC_FLAG_COMPRESSED:
     *
     * Compress values to the smallest possible size.
     */
    FWUPD_CODEC_FLAG_COMPRESSED = 1 << 1,
} G_GNUC_FLAG_ENUM FwupdCodecFlags;
