/*
 * This file is auto-generated, do not modify!
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#pragma once
#include <libfwupd/fwupd-build.h>
/**
 * FwupdJsonNodeKind:
 *
 * JSON node kind.
 */
typedef enum {
    /**
     * FWUPD_JSON_NODE_KIND_NULL:
     */
    FWUPD_JSON_NODE_KIND_NULL,
    /**
     * FWUPD_JSON_NODE_KIND_RAW:
     */
    FWUPD_JSON_NODE_KIND_RAW,
    /**
     * FWUPD_JSON_NODE_KIND_STRING:
     */
    FWUPD_JSON_NODE_KIND_STRING,
    /**
     * FWUPD_JSON_NODE_KIND_ARRAY:
     */
    FWUPD_JSON_NODE_KIND_ARRAY,
    /**
     * FWUPD_JSON_NODE_KIND_OBJECT:
     */
    FWUPD_JSON_NODE_KIND_OBJECT,
}  FwupdJsonNodeKind;
#define FWUPD_JSON_NODE_KIND_LAST 5
const gchar *fwupd_json_node_kind_to_string(FwupdJsonNodeKind val) G_GNUC_CONST;
/**
 * FwupdJsonExportFlags:
 *
 * JSON export flags.
 */
typedef enum {
    /**
     * FWUPD_JSON_EXPORT_FLAG_NONE:
     */
    FWUPD_JSON_EXPORT_FLAG_NONE = 0,
    /**
     * FWUPD_JSON_EXPORT_FLAG_INDENT:
     */
    FWUPD_JSON_EXPORT_FLAG_INDENT = 1 << 0,
    /**
     * FWUPD_JSON_EXPORT_FLAG_TRAILING_NEWLINE:
     */
    FWUPD_JSON_EXPORT_FLAG_TRAILING_NEWLINE = 2 << 0,
} G_GNUC_FLAG_ENUM FwupdJsonExportFlags;
/**
 * FwupdJsonLoadFlags:
 *
 * JSON load flags.
 */
typedef enum {
    /**
     * FWUPD_JSON_LOAD_FLAG_NONE:
     */
    FWUPD_JSON_LOAD_FLAG_NONE = 0,
    /**
     * FWUPD_JSON_LOAD_FLAG_TRUSTED:
     */
    FWUPD_JSON_LOAD_FLAG_TRUSTED = 1 << 0,
    /**
     * FWUPD_JSON_LOAD_FLAG_STATIC_KEYS:
     */
    FWUPD_JSON_LOAD_FLAG_STATIC_KEYS = 1 << 1,
} G_GNUC_FLAG_ENUM FwupdJsonLoadFlags;
