/*
 * This file is auto-generated, do not modify!
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#pragma once
#include <libfwupd/fwupd-build.h>
/**
 * FwupdError:
 *
 * The error code.
 */
typedef enum {
    /**
     * FWUPD_ERROR_INTERNAL:
     *
     * Internal error.
     */
    FWUPD_ERROR_INTERNAL,
    /**
     * FWUPD_ERROR_VERSION_NEWER:
     *
     * Installed newer firmware version.
     */
    FWUPD_ERROR_VERSION_NEWER,
    /**
     * FWUPD_ERROR_VERSION_SAME:
     *
     * Installed same firmware version.
     */
    FWUPD_ERROR_VERSION_SAME,
    /**
     * FWUPD_ERROR_ALREADY_PENDING:
     *
     * Already set to be installed offline.
     */
    FWUPD_ERROR_ALREADY_PENDING,
    /**
     * FWUPD_ERROR_AUTH_FAILED:
     *
     * Failed to get authentication.
     */
    FWUPD_ERROR_AUTH_FAILED,
    /**
     * FWUPD_ERROR_READ:
     *
     * Failed to read from device.
     */
    FWUPD_ERROR_READ,
    /**
     * FWUPD_ERROR_WRITE:
     *
     * Failed to write to the device.
     */
    FWUPD_ERROR_WRITE,
    /**
     * FWUPD_ERROR_INVALID_FILE:
     *
     * Invalid file format.
     */
    FWUPD_ERROR_INVALID_FILE,
    /**
     * FWUPD_ERROR_NOT_FOUND:
     *
     * No matching device exists.
     */
    FWUPD_ERROR_NOT_FOUND,
    /**
     * FWUPD_ERROR_NOTHING_TO_DO:
     *
     * Nothing to do.
     */
    FWUPD_ERROR_NOTHING_TO_DO,
    /**
     * FWUPD_ERROR_NOT_SUPPORTED:
     *
     * Action was not possible.
     */
    FWUPD_ERROR_NOT_SUPPORTED,
    /**
     * FWUPD_ERROR_SIGNATURE_INVALID:
     *
     * Signature was invalid.
     */
    FWUPD_ERROR_SIGNATURE_INVALID,
    /**
     * FWUPD_ERROR_AC_POWER_REQUIRED:
     *
     * AC power was required.
     */
    FWUPD_ERROR_AC_POWER_REQUIRED,
    /**
     * FWUPD_ERROR_PERMISSION_DENIED:
     *
     * Permission was denied.
     */
    FWUPD_ERROR_PERMISSION_DENIED,
    /**
     * FWUPD_ERROR_BROKEN_SYSTEM:
     *
     * User has configured their system in a broken way.
     */
    FWUPD_ERROR_BROKEN_SYSTEM,
    /**
     * FWUPD_ERROR_BATTERY_LEVEL_TOO_LOW:
     *
     * The system battery level is too low.
     */
    FWUPD_ERROR_BATTERY_LEVEL_TOO_LOW,
    /**
     * FWUPD_ERROR_NEEDS_USER_ACTION:
     *
     * User needs to do an action to complete the update.
     */
    FWUPD_ERROR_NEEDS_USER_ACTION,
    /**
     * FWUPD_ERROR_AUTH_EXPIRED:
     *
     * Failed to get auth as credentials have expired.
     */
    FWUPD_ERROR_AUTH_EXPIRED,
    /**
     * FWUPD_ERROR_INVALID_DATA:
     *
     * Invalid data.
     */
    FWUPD_ERROR_INVALID_DATA,
    /**
     * FWUPD_ERROR_TIMED_OUT:
     *
     * The request timed out.
     */
    FWUPD_ERROR_TIMED_OUT,
    /**
     * FWUPD_ERROR_BUSY:
     *
     * The device is busy.
     */
    FWUPD_ERROR_BUSY,
    /**
     * FWUPD_ERROR_NOT_REACHABLE:
     *
     * The network is not reachable.
     */
    FWUPD_ERROR_NOT_REACHABLE,
}  FwupdError;
#define FWUPD_ERROR_LAST 22
